@@ -17,9 +17,13 @@ static const gchar developers[] =
     "Dirk Kähler\n"
     "Miroslav Valtr\n"
     "Martin Hasoň\n"
+    "Philipp Rahe\n"
 ;
 static const gchar translators[] =
+    "David Nečas (Yeti)\n"
+    "Petr Klapetek\n"
     "Livia Della Seta\n"
     "Philipp Leufke\n"
     "François Riguet\n"
+    "Даниил Браташов\n"
 ;
