@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwydatawindow.c 7185 2006-12-12 18:39:58Z yeti-dn $
+ *  @(#) $Id: gwydatawindow.c 8884 2008-12-28 12:17:44Z yeti-dn $
  *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -144,7 +144,7 @@ gwy_data_window_init(GwyDataWindow *data_window)
         gtk_object_sink(GTK_OBJECT(tooltips));
     }
 
-    data_window->data_name = g_string_new("");
+    data_window->data_name = g_string_new(NULL);
 }
 
 static void
