@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: inttrans.c 8634 2007-10-11 20:42:31Z yeti-dn $
+ *  @(#) $Id: inttrans.c 8874 2008-12-28 12:16:22Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -799,7 +799,7 @@ gwy_data_field_2dfft_real_do(GwyDataField *rin,
     }
     if (rin->yres % 2) {
         k = rin->xres * (rin->yres - 1);
-        memset(ibuf->data, 0, rin->xres*sizeof(gdouble));
+        gwy_clear(ibuf->data, rin->xres);
         gwy_fft_simple(direction, rin->xres,
                        1, rin->data + k, ibuf->data,
                        1, rout->data + k, iout->data + k);
@@ -1464,7 +1464,7 @@ gwy_data_field_xfft_real_do(GwyDataField *rin,
     }
     if (rin->yres % 2) {
         k = rin->xres * (rin->yres - 1);
-        memset(ibuf->data, 0, rin->xres*sizeof(gdouble));
+        gwy_clear(ibuf->data, rin->xres);
         gwy_fft_simple(direction, rin->xres,
                        1, rin->data + k, ibuf->data,
                        1, rout->data + k, iout->data + k);
