@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: simplefft.c 8325 2007-07-10 19:06:35Z yeti-dn $
+ *  @(#) $Id: simplefft.c 8874 2008-12-28 12:16:22Z yeti-dn $
  *  Copyright (C) 2003-2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -792,8 +792,8 @@ bluestein(guint n,
         are[j] = bre[j]*in_re[istride*j] + bim[j]*in_im[istride*j];
         aim[j] = bre[j]*in_im[istride*j] - bim[j]*in_re[istride*j];
     }
-    memset(are + n, 0, sizeof(gdouble)*(nfft - n));
-    memset(aim + n, 0, sizeof(gdouble)*(nfft - n));
+    gwy_clear(are + n, nfft - n);
+    gwy_clear(aim + n, nfft - n);
     gwy_fft_simple(GWY_TRANSFORM_DIRECTION_FORWARD, nfft,
                    1, are, aim, 1, are + 2*nfft, aim + 2*nfft);
 
