@@ -1,5 +1,5 @@
 /*
- *  $Id: hdf4file.c 8646 2007-10-17 13:34:35Z yeti-dn $
+ *  $Id: hdf4file.c 8950 2009-01-02 12:00:56Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
@@ -417,7 +417,6 @@ psi_load(const gchar *filename,
 
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
-        g_clear_error(&err);
         return NULL;
     }
 
@@ -891,7 +890,7 @@ hdf4_describe_tag(const HDF4DataDescriptor *desc)
     gchar *s;
     guint i;
 
-    str = g_string_new("");
+    str = g_string_new(NULL);
     if (desc->tag == HDF4_NULL)
         goto finish;
 
