@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: jpkscan.c 8290 2007-07-08 16:04:03Z yeti-dn $
+ *  @(#) $Id: jpkscan.c 8950 2009-01-02 12:00:56Z yeti-dn $
  *  Loader for JPK Image Scans.
  *  Copyright (C) 2005  JPK Instruments AG.
  *  Written by Sven Neumann <neumann@jpk.com>.
@@ -442,7 +442,7 @@ tiff_load_channel(TIFF *tiff,
 
     /* Add the GwyDataField to the container */
 
-    key = g_string_new("");
+    key = g_string_new(NULL);
     g_string_printf(key, "/%d/data", idx);
     gwy_container_set_object_by_name(container, key->str, dfield);
     g_object_unref(dfield);
