@@ -1,5 +1,5 @@
 /*
- *  $Id: omicron.c 8625 2007-10-10 20:03:12Z yeti-dn $
+ *  $Id: omicron.c 8916 2008-12-30 12:48:54Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
@@ -23,7 +23,7 @@
  * [FILE-MAGIC-FREEDESKTOP]
  * <mime-type type="application/x-omicron-spm">
  *   <comment>Omicron SCALA data parameters</comment>
- *   <magic priority="50">
+ *   <magic priority="80">
  *     <match type="string" offset="0:160" value="Omicron SPM Control"/>
  *   </magic>
  *   <glob pattern="*.par"/>
@@ -137,7 +137,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Omicron data files (two-part .par + .tf*, .tb*, .sf*, .sb*)."),
     "Yeti <yeti@gwyddion.net>",
-    "0.5",
+    "0.6",
     "David Nečas (Yeti) & Petr Klapetek & Markus Pristovsek",
     "2006",
 };
@@ -892,7 +892,8 @@ omicron_read_cs_data(OmicronFile *ofile,
 
     for (i = 0; i < ncurves; i++) {
         dline = g_ptr_array_index(spectrum, i);
-        gwy_spectra_add_spectrum(spectra, dline, coords[i*2], coords[i*2+1]);
+        gwy_spectra_add_spectrum(spectra, dline,
+                                 coords[i*2], ofile->yreal - coords[i*2+1]);
         g_object_unref(dline);
     }
 
