@@ -1,5 +1,5 @@
 /*
- *  $Id: rhk-spm32.c 8673 2007-10-28 22:54:18Z yeti-dn $
+ *  $Id: rhk-spm32.c 8950 2009-01-02 12:00:56Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -22,7 +22,7 @@
  * [FILE-MAGIC-FREEDESKTOP]
  * <mime-type type="application/x-rhk-sm2-spm">
  *   <comment>RHK SM2 SPM data</comment>
- *   <magic priority="50">
+ *   <magic priority="80">
  *     <match type="string" offset="0" value="STiMage 3.1"/>
  *   </magic>
  *   <glob pattern="*.sm2"/>
@@ -271,7 +271,7 @@ rhkspm32_load(const gchar *filename,
     g_clear_error(&err);
 
     container = gwy_container_new();
-    key = g_string_new("");
+    key = g_string_new(NULL);
     for (i = 0; i < rhkfile->len; i++) {
         const gchar *cs;
         gchar *s;
@@ -377,7 +377,7 @@ rhkspm32_read_header(RHKPage *rhkpage,
     if ((rhkpage->type == RHK_TYPE_IMAGE)
         && (rhkpage->data_type != RHK_DATA_INT16)) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
-                    _("rhk=spm32: invalid data type %d for image data."),
+                    _("Invalid data type %d for image data."),
                     rhkpage->data_type);
         return FALSE;
     }
@@ -385,7 +385,7 @@ rhkspm32_read_header(RHKPage *rhkpage,
         && !((rhkpage->data_type == RHK_DATA_INT16)
              || (rhkpage->data_type == RHK_DATA_SINGLE))) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
-                    _("rhk=spm32: invalid data type %d for line data."),
+                    _("Invalid data type %d for line data."),
                     rhkpage->data_type);
         return FALSE;
     }
