@@ -1,5 +1,5 @@
 /*
- *  $Id: stpfile.c 8721 2008-04-09 00:01:07Z sidewinderasu $
+ *  $Id: stpfile.c 8950 2009-01-02 12:00:56Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klstptek.
  *  E-mail: yeti@gwyddion.net, klstptek@gwyddion.net.
  *
@@ -27,8 +27,8 @@
 /**
  * [FILE-MAGIC-FREEDESKTOP]
  * <mime-type type="application/x-stp-spm">
- *   <comment>STP SPM data</comment>
- *   <magic priority="50">
+ *   <comment>Molecular Imaging STP SPM data</comment>
+ *   <magic priority="80">
  *     <match type="string" offset="0" value="UK SOFT\r\n"/>
  *   </magic>
  *   <glob pattern="*.stp"/>
@@ -125,7 +125,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Molecular Imaging STP data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.5",
+    "0.5.1",
     "David Nečas (Yeti), Petr Klapetek, Chris Anderson",
     "2006",
 };
@@ -250,14 +250,7 @@ find_data_start(const guchar *buffer,
                 gsize size)
 {
     const guchar *p;
-
-    size -= DATA_MAGIC_SIZE;
-
-    for (p = buffer;
-         p && strncmp(p, DATA_MAGIC, DATA_MAGIC_SIZE);
-         p = memchr(p+1, (DATA_MAGIC)[0], size - (p - buffer) - 1))
-        ;
-
+    p = gwy_memmem(buffer, size, DATA_MAGIC, DATA_MAGIC_SIZE);
     return p ? (p - buffer) + DATA_MAGIC_SIZE : 0;
 }
 
@@ -452,7 +445,7 @@ process_metadata(STPFile *stpfile,
 
     /* Metadata */
     meta = gwy_container_new();
-    str = g_string_new("");
+    str = g_string_new(NULL);
 
     /* Global */
     for (i = 0; i < G_N_ELEMENTS(global_metadata); i++) {
