@@ -1,5 +1,5 @@
 /*
- *  $Id: witfile.c 8530 2007-09-17 18:41:43Z yeti-dn $
+ *  $Id: witfile.c 8950 2009-01-02 12:00:56Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -282,7 +282,7 @@ witec_load(const gchar *filename,
     }
 
     container = gwy_container_new();
-    key = g_string_new("");
+    key = g_string_new(NULL);
     for (i = 0; i < witfile.header.channels; i++) {
         dfield = witec_image_to_data_field(&witfile, i);
         g_string_printf(key, "/%d/data", i);
