@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: point.c 8638 2007-10-12 07:10:41Z yeti-dn $
+ *  @(#) $Id: point.c 8805 2008-11-28 10:21:37Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -179,10 +179,8 @@ gwy_layer_point_class_init(GwyLayerPointClass *klass)
          PROP_MARKER_RADIUS,
          g_param_spec_uint("marker-radius",
                            "Marker radius",
-                           "fill me in",
-                           0,
-                           50,
-                           0,
+                           "Radius of marker to draw",
+                           0, 50, 0,
                            G_PARAM_READWRITE));
 }
 
