@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: polydistort.c 8263 2007-06-25 21:21:28Z yeti-dn $
- *  Copyright (C) 2007 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: polydistort.c 8912 2008-12-30 12:42:18Z yeti-dn $
+ *  Copyright (C) 2007,2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -49,6 +49,11 @@ typedef enum {
     PREVIEW_LAST
 } DistortPreviewType;
 
+enum {
+    RESPONSE_RESET   = 1,
+    RESPONSE_PREVIEW = 2
+};
+
 /* Data for this function. */
 typedef struct {
     DistortPreviewType preview_type;
@@ -81,6 +86,8 @@ static void       polydistort                   (GwyContainer *data,
 static void       distort_dialog                (DistortArgs *args,
                                                  GwyContainer *data,
                                                  GwyDataField *dfield,
+                                                 GwyDataField *mfield,
+                                                 GwyDataField *sfield,
                                                  gint id);
 static GtkWidget* coeff_table_new               (GtkWidget **entry,
                                                  gpointer id,
@@ -95,6 +102,8 @@ static void       update_changed                (GtkToggleButton *check,
 static void       run_noninteractive            (DistortArgs *args,
                                                  GwyContainer *data,
                                                  GwyDataField *dfield,
+                                                 GwyDataField *mfield,
+                                                 GwyDataField *sfield,
                                                  GwyDataField *result,
                                                  gint id);
 static void       distort_dialog_update_controls(DistortControls *controls,
@@ -130,7 +139,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Apllies polynomial distortion in the horizontal plane."),
     "Yeti <yeti@gwyddion.net>",
-    "1.2",
+    "1.4",
     "David Nečas (Yeti) & Petr Klapetek",
     "2007",
 };
@@ -156,7 +165,7 @@ static void
 polydistort(GwyContainer *data, GwyRunType run)
 {
     DistortArgs args;
-    GwyDataField *dfield;
+    GwyDataField *dfield, *mfield, *sfield;
     gint id;
 
     g_return_if_fail(run & DISTORT_RUN_MODES);
@@ -164,14 +173,16 @@ polydistort(GwyContainer *data, GwyRunType run)
     args.ycoeff = g_new(gdouble, NCOEFF);
     distort_load_args(gwy_app_settings_get(), &args);
     gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD, &dfield,
+                                     GWY_APP_MASK_FIELD, &mfield,
+                                     GWY_APP_SHOW_FIELD, &sfield,
                                      GWY_APP_DATA_FIELD_ID, &id,
                                      0);
     g_return_if_fail(dfield);
 
     if (run == GWY_RUN_IMMEDIATE)
-        run_noninteractive(&args, data, dfield, NULL, id);
+        run_noninteractive(&args, data, dfield, mfield, sfield, NULL, id);
     else {
-        distort_dialog(&args, data, dfield, id);
+        distort_dialog(&args, data, dfield, mfield, sfield, id);
         distort_save_args(gwy_app_settings_get(), &args);
     }
 
@@ -183,13 +194,10 @@ static void
 distort_dialog(DistortArgs *args,
                GwyContainer *data,
                GwyDataField *dfield,
+               GwyDataField *mfield,
+               GwyDataField *sfield,
                gint id)
 {
-    enum {
-        RESPONSE_RESET   = 1,
-        RESPONSE_PREVIEW = 2
-    };
-
     GtkWidget *dialog, *table, *hbox, *label;
     DistortControls controls;
     gint response;
@@ -206,6 +214,8 @@ distort_dialog(DistortArgs *args,
                                  gwy_stock_like_button_new(_("_Update"),
                                                            GTK_STOCK_EXECUTE),
                                  RESPONSE_PREVIEW);
+    gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), RESPONSE_PREVIEW,
+                                      !args->update);
     gtk_dialog_add_button(GTK_DIALOG(dialog), _("_Reset"), RESPONSE_RESET);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
                           GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
@@ -376,10 +386,11 @@ distort_dialog(DistortArgs *args,
     gtk_widget_destroy(dialog);
 
     if (controls.computed)
-        run_noninteractive(args, data, dfield, controls.result, id);
+        run_noninteractive(args, data, dfield, mfield, sfield,
+                           controls.result, id);
     else {
         gwy_object_unref(controls.result);
-        run_noninteractive(args, data, dfield, NULL, id);
+        run_noninteractive(args, data, dfield, mfield, sfield, NULL, id);
     }
 }
 
@@ -476,6 +487,9 @@ update_changed(GtkToggleButton *check,
                DistortControls *controls)
 {
     controls->args->update = gtk_toggle_button_get_active(check);
+    gtk_dialog_set_response_sensitive(GTK_DIALOG(controls->dialog),
+                                      RESPONSE_PREVIEW,
+                                      !controls->args->update);
     if (controls->args->update)
         preview(controls, controls->args);
 }
@@ -485,6 +499,8 @@ static void
 run_noninteractive(DistortArgs *args,
                    GwyContainer *data,
                    GwyDataField *dfield,
+                   GwyDataField *mfield,
+                   GwyDataField *sfield,
                    GwyDataField *result,
                    gint id)
 {
@@ -498,11 +514,34 @@ run_noninteractive(DistortArgs *args,
     newid = gwy_app_data_browser_add_data_field(result, data, TRUE);
     gwy_app_set_data_field_title(data, newid, _("Distorted"));
     gwy_app_sync_data_items(data, data, id, newid, FALSE,
-                            GWY_DATA_ITEM_PALETTE,
+                            GWY_DATA_ITEM_GRADIENT,
                             GWY_DATA_ITEM_RANGE,
+                            GWY_DATA_ITEM_MASK_COLOR,
+                            GWY_DATA_ITEM_REAL_SQUARE,
                             0);
 
     g_object_unref(result);
+
+
+    if (mfield) {
+        GwyInterpolationType interp = args->interp;
+
+        result = gwy_data_field_duplicate(mfield);
+        args->interp = GWY_INTERPOLATION_ROUND;
+        distort_do(args, mfield, result);
+        args->interp = interp;
+        gwy_container_set_object(data, gwy_app_get_mask_key_for_id(newid),
+                                 result);
+        g_object_unref(result);
+    }
+
+    if (sfield) {
+        result = gwy_data_field_duplicate(sfield);
+        distort_do(args, sfield, result);
+        gwy_container_set_object(data, gwy_app_get_show_key_for_id(newid),
+                                 result);
+        g_object_unref(result);
+    }
 }
 
 static void
