@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: pygwy.c 8726 2008-04-28 14:23:32Z xhorak $
+ *  @(#) $Id: pygwy.c 8836 2008-12-12 14:23:42Z xhorak $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -24,30 +24,23 @@
  * own copy of main dictionary created by create_environment() function
  * and destroyed by destroy_environment() which deallocate created copy.
  */
-
 #include "config.h"
 
+
 /* include this first, before NO_IMPORT_PYGOBJECT is defined */
 #include <pygtk-2.0/pygobject.h>
-
-#include <string.h>
-#include <glib.h>
-#include <glib/gstdio.h>
-#include <gtk/gtk.h>
-#include <libgwyddion/gwymath.h>
-#include <libgwyddion/gwymacros.h>
-#include <libprocess/gwyprocess.h>
-#include <libgwymodule/gwymodule.h>
-#include <libgwymodule/gwymodule-process.h>
-#include <libgwymodule/gwymodule-file.h>
 #include <app/gwyapp.h>
 #include "wrap_calls.h"
+#include <glib/gstdio.h>
+#include "pygwy.h"
 
-static GValue*    convert_pyobject_to_gvalue         (PyObject *o);
-static PyObject*  convert_gvalue_to_pyobject         (GValue *value);
+
+//static GValue*    convert_pyobject_to_gvalue         (PyObject *o);
+//static PyObject*  convert_gvalue_to_pyobject         (GValue *value);
 static void       pygwy_create_py_list_of_containers (GwyContainer *data, gpointer list);
 #include "pygwywrap.c"
-#line 52 "pygwy.c"
+#include "pygwy-console.h"
+#line 43 "pygwy.c"
 
 typedef struct {
     gchar *name;
@@ -56,17 +49,12 @@ typedef struct {
     time_t m_time;
 } PygwyPluginInfo;
 
-typedef struct {
-   PyObject *std_err;
-   PyObject *dictionary;
-   GtkWidget *console_output;
-   GtkWidget *console_file_content;
-} PygwyConsoleSetup;
 
 typedef enum {
-    PYGWY_PROCESS, PYGWY_FILE, PYGWY_GRAPH, PYGWY_LAYER, PYGWY_UNDEFINED
+    PYGWY_PROCESS, PYGWY_FILE, PYGWY_GRAPH, PYGWY_LAYER, PYGWY_TOOL, PYGWY_UNDEFINED
 } PygwyPluginType;
 
+const gchar pygwy_plugin_dir_name[] = "pygwy";
 
 static gboolean         module_register       (void);
 static void             pygwy_proc_run        (GwyContainer *data,
@@ -74,11 +62,6 @@ static void             pygwy_proc_run        (GwyContainer *data,
                                                const gchar *name);
 static void             pygwy_graph_run       (GwyGraph *graph,
                                                const gchar *name);
-static void             pygwy_console_run     (GwyContainer *data,
-                                               GwyRunType run,
-                                               const gchar *name);
-static void             pygwy_register_plugins(void);
-static void             pygwy_register_console(void);
 static PygwyPluginInfo* pygwy_find_plugin     (const gchar* name);
 static gboolean         pygwy_file_save_run   (GwyContainer *data,
                                                const gchar *filename,
@@ -93,17 +76,15 @@ static gint             pygwy_file_detect_run (const GwyFileDetectInfo
                                                *fileinfo,
                                                gboolean only_name,
                                                gchar *name);
-static void             pygwy_on_console_command_execute(GtkEntry *entry, 
-                                                         gpointer user_data);
+static void             pygwy_register_plugins(void);
 
-static gboolean         pygwy_on_console_close(GtkWidget *widget, 
-                                               GdkEvent *event, 
-                                               gpointer user_data);
-static GList *s_pygwy_plugins = NULL;
-static PygwyConsoleSetup *s_console_setup = NULL;
-static PyObject *s_pygwy_dict;
-static PyObject *s_main_module;
-const gchar pygwy_plugin_dir_name[] = "pygwy";
+typedef struct {
+   GList *plugins;
+   PyObject *dict;
+   PyObject *main_module;
+} PygwyModuleInfo;
+
+static PygwyModuleInfo s_pygwy;
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -126,7 +107,7 @@ module_register(void)
 }
 
 
-static void
+void
 pygwy_initialize(void)
 {
     PyObject *m;
@@ -136,17 +117,17 @@ pygwy_initialize(void)
         // Do not register signal handlers
         Py_InitializeEx(0);
         gwy_debug("Add main module");
-        s_main_module = PyImport_AddModule("__main__");
+        s_pygwy.main_module = PyImport_AddModule("__main__");
         gwy_debug("Init pygobject");
         init_pygobject();
 
         gwy_debug("Init module gwy");
         m = Py_InitModule("gwy", (PyMethodDef*) pygwy_functions);
         gwy_debug("Get dict");
-        s_pygwy_dict = PyModule_GetDict(m);
+        s_pygwy.dict = PyModule_GetDict(m);
 
         gwy_debug("Register classes");
-        pygwy_register_classes(s_pygwy_dict);
+        pygwy_register_classes(s_pygwy.dict);
         gwy_debug("Register constaints");
         pygwy_add_constants(m, "GWY_");
      } else {
@@ -154,7 +135,7 @@ pygwy_initialize(void)
     }
 }
 
-static PyObject*
+PyObject*
 pygwy_run_string(const char *cmd, int type, PyObject *g, PyObject *l) {
     PyObject *ret = PyRun_String(cmd, type, g, l);
     if (!ret) {
@@ -169,7 +150,7 @@ pygwy_show_stderr(gchar *str)
     GtkWidget *dlg, *scroll, *frame, *b_close, *text;
 
     dlg = gtk_dialog_new();
-    gtk_window_set_default_size(GTK_WINDOW(dlg), 500, 300);
+    gtk_window_set_default_size(GTK_WINDOW(dlg), 600, 350);
     gtk_window_set_position (GTK_WINDOW (dlg), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_window_set_title(GTK_WINDOW(dlg), "Python interpreter result");
 
@@ -228,13 +209,13 @@ pygwy_finalize_stderr_redirect(PyObject *d)
     }
 }
 
-static PyObject *
+PyObject *
 create_environment(const gchar *filename, gboolean show_errors) {
     PyObject *d, *plugin_filename;
     char *argv[1];
     argv[0] = NULL;
 
-    d = PyDict_Copy(PyModule_GetDict(s_main_module));
+    d = PyDict_Copy(PyModule_GetDict(s_pygwy.main_module));
     // set __file__ variable for clearer error reporting
     plugin_filename = Py_BuildValue("s", filename);
     PyDict_SetItemString(d, "__file__", plugin_filename);
@@ -246,7 +227,7 @@ create_environment(const gchar *filename, gboolean show_errors) {
     return d;
 }
 
-static void
+void
 destroy_environment(PyObject *d, gboolean show_errors) {
     // show content of temporary file which contains stderr and stdout of python
     // script and close it
@@ -287,8 +268,9 @@ pygwy_get_plugin_metadata(const gchar *filename,
                           PygwyPluginType *type)
 {
     gchar *plugin_file_content, *type_str, *suffix;
-    PyObject *code_obj = NULL, *plugin_module = NULL, *d, *plugin_dict;
+    PyObject *plugin_module = NULL, *d, *plugin_dict;
     GError *err = NULL;
+    gboolean error = FALSE;
 
     *code = NULL; *name = NULL; *menu_path = NULL; *type = PYGWY_UNDEFINED;
 
@@ -300,28 +282,30 @@ pygwy_get_plugin_metadata(const gchar *filename,
         return;
     }
     d = create_environment(filename, TRUE);
+    // clear read values
+
     if (!d) {
         g_warning("Cannot create copy of Python dictionary.");
         PyErr_Print();
-        *code = NULL;
-        return;
+        error = TRUE;
+        goto error;
     }
     // compile file of given filename to module
-    code_obj = Py_CompileString((char *)plugin_file_content,
+    *code = Py_CompileString((char *)plugin_file_content,
                                 module,
                                 Py_file_input); // new ref
-    if (!code_obj) {
+    if (!(*code)) {
         g_warning("Cannot compile plugin file '%s'", filename);
         PyErr_Print();
+        error = TRUE;
         goto error;
     }
-    *code = code_obj;
     // Execute compiled module
-    plugin_module = PyImport_ExecCodeModule("get_data", code_obj); // new ref
+    plugin_module = PyImport_ExecCodeModule("get_data", *code); // new ref
     if (!plugin_module) {
         g_warning("Cannot exec plugin code in file '%s'", filename);
         PyErr_Print();
-        *code = NULL;
+        error = TRUE;
         goto error;
     }
     plugin_dict = PyModule_GetDict(plugin_module);
@@ -333,6 +317,13 @@ pygwy_get_plugin_metadata(const gchar *filename,
     *desc = pygwy_read_val_from_dict(plugin_dict, "plugin_desc", filename);
     *menu_path = pygwy_read_val_from_dict(plugin_dict, "plugin_menu", filename);
     type_str = pygwy_read_val_from_dict(plugin_dict, "plugin_type", filename);
+    gwy_debug("read values: %s %s %s %x %x %x", *desc, *menu_path, type_str, *desc, *menu_path, type_str);
+    if (!type_str) {
+       g_warning("Undefined plugin type, cannot load.");
+       *type = PYGWY_UNDEFINED;
+       error = TRUE;
+       goto error;
+    }
     // FIXME: move string somewhere else
     if (g_ascii_strcasecmp ("PROCESS", type_str) == 0) {
         *type = PYGWY_PROCESS;
@@ -342,14 +333,17 @@ pygwy_get_plugin_metadata(const gchar *filename,
         *type = PYGWY_GRAPH;
     } else if (g_ascii_strcasecmp ("LAYER", type_str) == 0) {
         *type = PYGWY_LAYER;
+    } else if (g_ascii_strcasecmp ("TOOL", type_str) == 0) {
+        *type = PYGWY_TOOL;
     } else {
         g_warning("Unknown type '%s' in '%s'", type_str, filename);
         *type = PYGWY_UNDEFINED;
     }
 
 error:
-    if (!(*code)) {
-        Py_XDECREF(code_obj);
+    if (error) {
+       Py_XDECREF(*code);
+       *code = NULL;
     }
     Py_XDECREF(plugin_module);
     g_free(plugin_file_content);
@@ -402,7 +396,7 @@ pygwy_register_file_plugin(gchar *filename,
                                (GwyFileLoadFunc)&pygwy_file_load_run,
                                NULL,
                                (GwyFileSaveFunc)&pygwy_file_save_run)) {
-        s_pygwy_plugins = g_list_append(s_pygwy_plugins, info);
+        s_pygwy.plugins = g_list_append(s_pygwy.plugins, info);
     } else {
         gwy_debug("Free: %s %s", info->name, info->filename);
         // FIXME: Terminated by glib free(): invalid pointer: blabla
@@ -434,7 +428,7 @@ pygwy_register_proc_plugin(gchar *filename,
         return FALSE;
     }
     if (!menu_path) {
-        g_warning("Cannot register. Undefined 'plugin_desc' variable in '%s'",
+        g_warning("Cannot register. Undefined 'menu_path' variable in '%s'",
                   filename);
         return FALSE;
     }
@@ -449,7 +443,7 @@ pygwy_register_proc_plugin(gchar *filename,
                                   GWY_MENU_FLAG_DATA, // TODO: determine correct flag
                                   N_("Function written in Python")) ) { // not very descriptive
         // append plugin to list of plugins
-        s_pygwy_plugins = g_list_append(s_pygwy_plugins, info);
+        s_pygwy.plugins = g_list_append(s_pygwy.plugins, info);
     } else {
         // FIXME: Terminated by glib free(): invalid pointer: blabla
         // when inserting duplicate module
@@ -495,7 +489,7 @@ pygwy_register_graph_plugin(gchar *filename,
                                 GWY_MENU_FLAG_GRAPH, // TODO: determine correct flag
                                 N_("Graph function written in Python")) ) { // not very descriptive
         // append plugin to list of plugins
-        s_pygwy_plugins = g_list_append(s_pygwy_plugins, info);
+        s_pygwy.plugins = g_list_append(s_pygwy.plugins, info);
     } else {
         // FIXME: Terminated by glib free(): invalid pointer: blabla
         // when inserting duplicate module
@@ -519,7 +513,10 @@ pygwy_register_plugins(void)
     gchar *plugin_dir_name, *plugin_name, *plugin_desc = NULL;
     PygwyPluginType plugin_type = PYGWY_UNDEFINED;
     GError *err = NULL;
-    PyObject *plugin_code;
+    PyObject *plugin_code, *dict;
+
+    // reset static list 
+    s_pygwy.plugins = NULL;
 
     plugin_dir_name = g_build_filename(gwy_get_user_dir(),
                                        pygwy_plugin_dir_name,
@@ -578,10 +575,9 @@ pygwy_register_plugins(void)
                                                    plugin_name,
                                                    plugin_menu_path);
                     } else {
-                        g_warning("Could not register process: "
+                        g_warning("Could not register process module: "
                                   "variables plugin_menu, "
                                   "plugin_type and plugin_name not defined.");
-
                     }
                     break;
                 case PYGWY_FILE:
@@ -594,16 +590,11 @@ pygwy_register_plugins(void)
                                                plugin_name,
                                                plugin_desc);
                     } else {
-                        g_warning("Could not register process:"
+                        g_warning("Could not register file module:"
                                   " variables plugin_desc, plugin_type"
                                   " and plugin_name not defined.");
                     }
                     break;
-                case PYGWY_UNDEFINED:
-                    g_warning("Cannot register plugin without defined "
-                              "'plugin_type' variable  ('%s')",
-                              plugin_fullpath_filename);
-                    break;
                 case PYGWY_GRAPH:
                     printf("%s %s\n", plugin_name, plugin_desc);
                     if (plugin_code && plugin_name && plugin_desc) {
@@ -619,13 +610,37 @@ pygwy_register_plugins(void)
                     }
 
                     break;
+                case PYGWY_UNDEFINED:
+                    g_warning("Cannot register plugin without defined "
+                              "'plugin_type' variable  ('%s')",
+                              plugin_fullpath_filename);
+                    break;
                 default:
-                    g_warning("Rest of plugin types not yet implemented"); //TODO: PYGWY_GRAPH, PYGWY_LAYER
+                    g_warning("Rest of plugin types not yet implemented"); //TODO: PYGWY_LAYER, PYGWY_TOOL
+            } // switch
+            // reset plugin_code, plugin_name, plugin_desc, plugin_menu_path, plugin_type
+            plugin_name = NULL;
+            plugin_desc = NULL;
+            plugin_menu_path = NULL;
+            plugin_type = PYGWY_UNDEFINED;
+            // remove variables from dictionary
+            dict = PyModule_GetDict(s_pygwy.main_module);
+            if (dict && PyDict_GetItemString(dict, "plugin_desc")) {
+               gwy_debug("remove plugin_desc");
+               PyDict_DelItemString(dict, "plugin_desc");
+            }
+            if (dict && PyDict_GetItemString(dict, "plugin_menu")) {
+               gwy_debug("remove plugin_menu");
+               PyDict_DelItemString(dict, "plugin_menu");
+            }
+            if (dict && PyDict_GetItemString(dict, "plugin_type")) {
+               gwy_debug("remove plugin_type");
+               PyDict_DelItemString(dict, "plugin_type");
             }
         } else { // if (check suffix)
             gwy_debug("wrong extension for file: %s", plugin_filename);
         }
-    }
+   }
     g_dir_close(plugin_dir);
     g_free(plugin_dir_name);
 }
@@ -737,7 +752,7 @@ pygwy_proc_run(GwyContainer *data, GwyRunType run, const gchar *name)
     if (!py_container) {
         g_warning("Variable 'gwy.data' was not inicialized.");
     }
-    PyDict_SetItemString(s_pygwy_dict, "data", py_container);
+    PyDict_SetItemString(s_pygwy.dict, "data", py_container);
 
     // import module using precompiled code and run its 'run()' function
     cmd = g_strdup_printf("import %s\n"
@@ -792,7 +807,7 @@ pygwy_graph_run(GwyGraph *graph, const gchar *name)
     if (!py_graph) {
         g_warning("Variable 'gwy.data' was not inicialized.");
     }
-    PyDict_SetItemString(s_pygwy_dict, "graph", py_graph);
+    PyDict_SetItemString(s_pygwy.dict, "graph", py_graph);
 
     // import module using precompiled code and run its 'run()' function
     cmd = g_strdup_printf("import %s\n"
@@ -1044,7 +1059,7 @@ pygwy_file_detect_run(const GwyFileDetectInfo *fileinfo,
 static PygwyPluginInfo*
 pygwy_find_plugin(const gchar* name)
 {
-    GList *l = s_pygwy_plugins;
+    GList *l = s_pygwy.plugins;
     PygwyPluginInfo *info;
 
     while (l) {
@@ -1061,7 +1076,7 @@ pygwy_find_plugin(const gchar* name)
     }
     return (PygwyPluginInfo*)l->data;
 }
-
+/*
 static PyObject*
 convert_gvalue_to_pyobject(GValue *value)
 {
@@ -1115,17 +1130,17 @@ convert_gvalue_to_pyobject(GValue *value)
             break;
         case G_TYPE_OBJECT:
             o = pygobject_new((GObject *) g_value_get_object(value));
-/*
-        case G_TYPE_POINTER:
-        case G_TYPE_ENUM:
-        case G_TYPE_FLAGS:
-        case G_TYPE_INVALID:
-        case G_TYPE_NONE:
-        case G_TYPE_INTERFACE:
-        case G_TYPE_BOXED:
-        case G_TYPE_PARAM:
-        case G_TYPE_GTYPE:
-*/
+
+//        case G_TYPE_POINTER:
+//        case G_TYPE_ENUM:
+//        case G_TYPE_FLAGS:
+//        case G_TYPE_INVALID:
+//        case G_TYPE_NONE:
+//        case G_TYPE_INTERFACE:
+//       case G_TYPE_BOXED:
+//        case G_TYPE_PARAM:
+//        case G_TYPE_GTYPE:
+
     }
     return o;
 
@@ -1230,300 +1245,7 @@ convert_pyobject_to_gvalue(PyObject *o)
 
     return g_value;
 }
-
-static void
-pygwy_register_console()
-{
-
-    if (gwy_process_func_register(N_("Pygwy console"),
-                                  pygwy_console_run,
-                                  N_("/Pygwy console"),
-                                  NULL,
-                                  GWY_RUN_IMMEDIATE,
-                                  GWY_MENU_FLAG_DATA,
-                                  N_("Python wrapper console")) ) {
-
-    }
-}
-
-char *
-pygwy_console_run_command(gchar *cmd, int mode)
-{
-   if (!cmd) {
-      g_warning("No command.");
-      return NULL;
-   }
-
-   if (!s_console_setup) {
-      g_warning("Console setup structure is not defined!");
-      return NULL;
-   }
-   // store _stderr_redir location
-   pygwy_run_string(cmd, 
-         mode, 
-         s_console_setup->dictionary, 
-         s_console_setup->dictionary);
-   pygwy_run_string("_stderr_redir_pos = _stderr_redir.tell()\n"
-                    "_stderr_redir.seek(0)\n"
-                    "_stderr_redir_string = _stderr_redir.read(_stderr_redir_pos)\n"
-                    "_stderr_redir.seek(0)",
-         Py_file_input, 
-         s_console_setup->dictionary,
-         s_console_setup->dictionary);
-
-   return PyString_AsString( PyDict_GetItemString(
-            s_console_setup->dictionary, 
-            "_stderr_redir_string") );
-}
-
-static void
-pygwy_console_append(gchar *msg)
-{
-   GtkTextBuffer *console_buf;
-   GtkTextIter start_iter, end_iter;
-   GString *output;
-   GtkTextMark *end_mark;
-
-   if (!msg) {
-      g_warning("No message to append.");
-      return;
-   }
-   if (!s_console_setup) {
-      g_warning("Console setup structure is not defined!");
-      return;
-   }
-   // read string which contain last command output
-   console_buf = gtk_text_view_get_buffer(GTK_TEXT_VIEW(s_console_setup->console_output));
-   gtk_text_buffer_get_bounds(console_buf, &start_iter, &end_iter);
-
-   // get output widget content
-   output = g_string_new (gtk_text_buffer_get_text(console_buf, &start_iter, &end_iter, FALSE));
-
-   // append input line
-   output = g_string_append(output, msg);
-   gtk_text_buffer_set_text (GTK_TEXT_BUFFER (console_buf), output->str, -1);
-   g_string_free(output, TRUE);
-
-   // scroll to end
-   gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(console_buf), &end_iter);
-   end_mark = gtk_text_buffer_create_mark(console_buf, "cursor", &end_iter, FALSE);
-   g_object_ref(end_mark);
-   gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(s_console_setup->console_output), 
-         end_mark, 0.0, FALSE, 0.0, 0.0);
-   g_object_unref(end_mark);
-
-}
-
-static void
-pygwy_on_console_run_file(GtkToolButton *btn, gpointer user_data)
-{
-   GtkTextIter start_iter, end_iter;
-   char *output, *file_info_line;
-
-   GtkTextBuffer *console_file_buf = 
-      gtk_text_view_get_buffer(GTK_TEXT_VIEW(s_console_setup->console_file_content));
-
-   file_info_line = g_strdup_printf(">>> Running file content of below textfield\n");
-
-   pygwy_console_append(file_info_line);
-
-   gtk_text_buffer_get_bounds(console_file_buf, &start_iter, &end_iter);
-   output = pygwy_console_run_command(
-         gtk_text_buffer_get_text(console_file_buf, &start_iter, &end_iter, FALSE), 
-         Py_file_input);
-   pygwy_console_append(output);
-
-   // get output widget content
-   gtk_text_buffer_get_text(console_file_buf, &start_iter, &end_iter, FALSE);
-
-}
-
-
-static void
-pygwy_on_console_open_file(GtkToolButton *btn, gpointer user_data)
-{
-   GtkFileChooserDialog *file_chooser;
-   GtkFileFilter *filter = gtk_file_filter_new();
-   GtkTextBuffer *console_file_buf;
-   gtk_file_filter_add_mime_type(filter, "text/x-python");
-
-   file_chooser = gtk_file_chooser_dialog_new("Run Python script", 
-         NULL, 
-         GTK_FILE_CHOOSER_ACTION_OPEN,
-         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-	      GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
-         NULL);
-   gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(file_chooser), filter);
-   if (gtk_dialog_run (GTK_DIALOG (file_chooser)) == GTK_RESPONSE_ACCEPT)
-   {
-      char *filename, *output, *file_content;
-      GError *err = NULL;
-      
-
-      filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_chooser));
-      printf("Open: %s\n", filename);
-      if (!g_file_get_contents(filename,
-                            &file_content,
-                            NULL,
-                            &err)) {
-         g_warning("Cannot read content of file '%s'", filename);
-         return;
-      }
-      
-      // read string which contain last command output
-      console_file_buf = gtk_text_view_get_buffer(GTK_TEXT_VIEW(s_console_setup->console_file_content));
-
-      // append input line
-      gtk_text_buffer_set_text (GTK_TEXT_BUFFER (console_file_buf), file_content, -1);
-
-      g_free(file_content);
-      g_free(filename);
-   }
-   gtk_widget_destroy (file_chooser);
-}
-   
-static void 
-pygwy_console_create_gui()
-{
-   GtkWidget *console_win, *vbox1, *console_scrolledwin, *file_scrolledwin;
-   GtkWidget *entry_input, *button_bar, *button_open, *button_run;
-
-   // create static structure;
-   s_console_setup = g_malloc(sizeof(PygwyConsoleSetup));
-   // create GUI
-   console_win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-   gtk_window_set_title (GTK_WINDOW (console_win), "Pygwy Console");
-
-   vbox1 = gtk_vbox_new (FALSE, 0);
-   gtk_container_add (GTK_CONTAINER (console_win), vbox1);
-
-   // buttons
-   button_open = gtk_tool_button_new_from_stock(GTK_STOCK_OPEN);
-   button_run = gtk_tool_button_new_from_stock(GTK_STOCK_EXECUTE);
-   button_bar = gtk_toolbar_new();
-   gtk_toolbar_insert(GTK_TOOLBAR(button_bar), button_open, 0);
-   gtk_toolbar_insert(GTK_TOOLBAR(button_bar), button_run, 0);
-   gtk_box_pack_start(GTK_BOX(vbox1), button_bar, FALSE, FALSE, 0);
-
-   // window
-   file_scrolledwin = gtk_scrolled_window_new (NULL, NULL);
-   gtk_box_pack_start (GTK_BOX (vbox1), file_scrolledwin, TRUE, TRUE, 0);
-   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (file_scrolledwin), GTK_SHADOW_IN);
-
-   console_scrolledwin = gtk_scrolled_window_new (NULL, NULL);
-   gtk_box_pack_start (GTK_BOX (vbox1), console_scrolledwin, TRUE, TRUE, 0);
-   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (console_scrolledwin), GTK_SHADOW_IN);
-
-
-   // console output
-   s_console_setup->console_output = gtk_text_view_new ();
-   gtk_container_add (GTK_CONTAINER (console_scrolledwin), s_console_setup->console_output);
-   gtk_text_view_set_editable (GTK_TEXT_VIEW (s_console_setup->console_output), FALSE);
-
-   // file buffer
-   s_console_setup->console_file_content = gtk_text_view_new();
-   gtk_container_add (GTK_CONTAINER (file_scrolledwin), s_console_setup->console_file_content);
-   gtk_text_view_set_editable (GTK_TEXT_VIEW (s_console_setup->console_file_content), TRUE);
-
-   entry_input = gtk_entry_new ();
-   gtk_box_pack_start (GTK_BOX (vbox1), entry_input, FALSE, FALSE, 0);
-   gtk_entry_set_invisible_char (GTK_ENTRY (entry_input), 9679);
-   gtk_widget_grab_focus(GTK_WIDGET(entry_input));
-
-   // entry widget on ENTER
-   g_signal_connect ((gpointer) entry_input, "activate",
-         G_CALLBACK (pygwy_on_console_command_execute),
-         NULL);
-   // open script signal connect
-   g_signal_connect ((gpointer) button_open, "clicked",
-         G_CALLBACK (pygwy_on_console_open_file),
-         NULL);
-   g_signal_connect ((gpointer) button_run, "clicked",
-         G_CALLBACK (pygwy_on_console_run_file),
-         NULL);
-
-   // connect on window close()
-   g_signal_connect ((gpointer) console_win, "delete_event",
-         G_CALLBACK (pygwy_on_console_close),
-         NULL);
-   gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(s_console_setup->console_output), GTK_WRAP_WORD_CHAR);
-   gtk_window_resize(GTK_WINDOW(console_win), 600, 500);
-   gtk_widget_show_all(console_win);
-}
-
-static void
-pygwy_console_run(GwyContainer *data, GwyRunType run, const gchar *name)
-{
-    PyObject *d, *py_container;
-    gchar *plugin_dir_name = NULL, *sys_path_append;
-    
-    pygwy_initialize();      
-    pygwy_console_create_gui();
-    // create new environment    
-    d = create_environment("__console__", FALSE);
-    if (!d) {
-        g_warning("Cannot create copy of Python dictionary.");
-        return;
-    }
-
-    // create container named 'data' to allow access the container from python
-    py_container = pygobject_new((GObject*)data);
-    if (!py_container) {
-        g_warning("Variable 'gwy.data' was not inicialized.");
-    }
-    PyDict_SetItemString(s_pygwy_dict, "data", py_container);
-    
-    // redirect stdout & stderr to temporary file
-    pygwy_run_string("import sys, gwy, tempfile\n"
-                     "_stderr_redir = tempfile.TemporaryFile()\n"
-                     "sys.stderr = _stderr_redir\n"
-                     "sys.stdout = _stderr_redir\n",
-                     Py_file_input,
-                     d,
-                     d);
-
-    // add .gwyddion/pygwy to sys.path
-    plugin_dir_name = g_build_filename(gwy_get_user_dir(),
-                                       pygwy_plugin_dir_name,
-                                       NULL);
-    sys_path_append = g_strdup_printf("sys.path.append('%s')\n", plugin_dir_name);
-    pygwy_run_string(sys_path_append, Py_file_input, d, d);
-    g_free(sys_path_append);
-    g_free(plugin_dir_name);
-
-    // store values for closing console
-    s_console_setup->std_err = PyDict_GetItemString(d, "_stderr_redir");
-    Py_INCREF(s_console_setup->std_err);
-    s_console_setup->dictionary = d;
-}
-
-static void
-pygwy_on_console_command_execute(GtkEntry *entry, gpointer user_data)
-{
-    gchar *input_line;
-    GString *output;
-
-    input_line = g_strconcat(">>> ", gtk_entry_get_text(entry), "\n", NULL);
-    output = g_string_new(input_line);
-    output = g_string_append(output,  
-          pygwy_console_run_command(gtk_entry_get_text(entry), Py_single_input) );
-
-    pygwy_console_append(output->str);
-    g_string_free(output, TRUE);
-
-    gtk_editable_select_region(GTK_EDITABLE(entry), 0, -1);
-}
-
-static gboolean
-pygwy_on_console_close(GtkWidget *widget, GdkEvent *event, gpointer user_data)
-{
-    //Py_DECREF(module);
-    //Py_DECREF(py_container); //FIXME
-    Py_DECREF(s_console_setup->std_err);
-    destroy_environment(s_console_setup->dictionary, FALSE);
-    g_free(s_console_setup);
-    return FALSE;
-}
+*/
 
 // function to fill list of containers, for  gwy_app_data_browser_get_containers
 static void
@@ -1537,4 +1259,5 @@ pygwy_create_py_list_of_containers(GwyContainer *data, gpointer list)
 }
 
 
+
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
