@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: linestats.c 8340 2007-07-12 17:51:25Z yeti-dn $
- *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: linestats.c 8890 2008-12-28 12:18:43Z yeti-dn $
+ *  Copyright (C) 2003-2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 #include <libgwymodule/gwymodule-tool.h>
 #include <libprocess/gwyprocesstypes.h>
 #include <libprocess/stats.h>
+#include <libprocess/linestats.h>
 #include <libgwydgets/gwystock.h>
 #include <libgwydgets/gwycombobox.h>
 #include <libgwydgets/gwyradiobuttons.h>
@@ -75,6 +76,7 @@ struct _GwyToolLineStats {
     GtkWidget *interpolation_label;
     GtkWidget *update;
     GtkWidget *apply;
+    GtkWidget *average_label;
 
     /* potential class data */
     GType layer_type_rect;
@@ -121,7 +123,7 @@ static GwyModuleInfo module_info = {
     N_("Row/column statistical function tool, mean values, medians, maxima, "
        "minima, RMS, ..., of rows or columns."),
     "Yeti <yeti@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
@@ -149,10 +151,15 @@ static const GwyEnum sf_types[] =  {
     { N_("Median"),             GWY_LINE_STAT_MEDIAN,    },
     { N_("Minimum"),            GWY_LINE_STAT_MINIMUM,   },
     { N_("Maximum"),            GWY_LINE_STAT_MAXIMUM,   },
-    { N_("RMS"),                GWY_LINE_STAT_RMS,       },
     { N_("Length"),             GWY_LINE_STAT_LENGTH,    },
     { N_("Slope"),              GWY_LINE_STAT_SLOPE,     },
     { N_("tan β<sub>0</sub>"),  GWY_LINE_STAT_TAN_BETA0, },
+    { N_("Ra"),                 GWY_LINE_STAT_RA,        },
+    { N_("Rq (RMS)"),           GWY_LINE_STAT_RMS,       },
+    { N_("Rz"),                 GWY_LINE_STAT_RZ,        },
+    { N_("Rt"),                 GWY_LINE_STAT_RT,        },
+    { N_("Skew"),               GWY_LINE_STAT_SKEW,      },
+    { N_("Kurtosis"),           GWY_LINE_STAT_KURTOSIS,  },
 };
 
 GWY_MODULE_QUERY(module_info)
@@ -305,16 +312,34 @@ gwy_tool_line_stats_init_dialog(GwyToolLineStats *tool)
                        FALSE, FALSE, 0);
 
     /* Output type */
-    hbox2 = gtk_hbox_new(FALSE, 4);
+    hbox2 = gtk_hbox_new(FALSE, 8);
     gtk_container_set_border_width(GTK_CONTAINER(hbox2), 4);
     gtk_box_pack_start(GTK_BOX(vbox), hbox2, FALSE, FALSE, 0);
 
+    label = gtk_label_new_with_mnemonic(_("_Quantity:"));
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
+
     tool->output_type = gwy_enum_combo_box_new
                            (sf_types, G_N_ELEMENTS(sf_types),
                             G_CALLBACK(gwy_tool_line_stats_output_type_changed),
                             tool,
                             tool->args.output_type, TRUE);
+    gtk_label_set_mnemonic_widget(GTK_LABEL(label), tool->output_type);
     gtk_box_pack_start(GTK_BOX(hbox2), tool->output_type, FALSE, FALSE, 0);
+    
+    /* Average */
+    hbox2 = gtk_hbox_new(FALSE, 8);
+    gtk_container_set_border_width(GTK_CONTAINER(hbox2), 4);
+    gtk_box_pack_start(GTK_BOX(vbox), hbox2, FALSE, FALSE, 0);
+
+    label = gtk_label_new(_("Average:"));
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
+
+    tool->average_label = label = gtk_label_new(NULL);
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_box_pack_start(GTK_BOX(hbox2), label, TRUE, TRUE, 0);
 
     /* Options */
     tool->options = gtk_expander_new(_("<b>Options</b>"));
@@ -418,7 +443,7 @@ gwy_tool_line_stats_data_switched(GwyTool *gwytool,
     ignore = (data_view == plain_tool->data_view);
 
     GWY_TOOL_CLASS(gwy_tool_line_stats_parent_class)->data_switched(gwytool,
-                                                                 data_view);
+                                                                    data_view);
 
     if (ignore || plain_tool->init_failed)
         return;
@@ -496,9 +521,12 @@ gwy_tool_line_stats_update_curve(GwyToolLineStats *tool)
     GwyPlainTool *plain_tool;
     GwyGraphCurveModel *gcmodel;
     gdouble sel[4];
+    gchar result[100];
     gint isel[4] = { sizeof("Die, die, GCC!"), 0, 0, 0 };
     gint n, nsel, w = sizeof("Die, die, GCC!"), h = 0;
     const gchar *title;
+    GwySIUnit *siunit;
+    GwySIValueFormat *format;
 
     plain_tool = GWY_PLAIN_TOOL(tool);
 
@@ -510,6 +538,7 @@ gwy_tool_line_stats_update_curve(GwyToolLineStats *tool)
         zunit = gwy_data_field_get_si_unit_z(plain_tool->data_field);
         if (!gwy_si_unit_equal(xyunit, zunit)) {
             gwy_graph_model_remove_all_curves(tool->gmodel);
+            gtk_label_set_text(GTK_LABEL(tool->average_label), "");
             gtk_widget_set_sensitive(tool->apply, FALSE);
             return;
         }
@@ -546,6 +575,7 @@ gwy_tool_line_stats_update_curve(GwyToolLineStats *tool)
         return;
 
     if (nsel == 0 && n > 0) {
+        gtk_label_set_text(GTK_LABEL(tool->average_label), "");
         gwy_graph_model_remove_all_curves(tool->gmodel);
         return;
     }
@@ -575,6 +605,15 @@ gwy_tool_line_stats_update_curve(GwyToolLineStats *tool)
     g_object_set(gcmodel, "description", title, NULL);
     g_object_set(tool->gmodel, "title", title, NULL);
     gwy_graph_model_set_units_from_data_line(tool->gmodel, tool->line);
+
+    siunit = gwy_data_line_get_si_unit_y(tool->line);
+    format = gwy_si_unit_get_format(siunit, GWY_SI_UNIT_FORMAT_MARKUP, 
+                                    gwy_data_line_get_avg(tool->line), NULL);
+    g_snprintf(result, sizeof(result), "(%.4g ± %.4g) %s",  
+               gwy_data_line_get_avg(tool->line)/format->magnitude,
+               gwy_data_line_get_rms(tool->line)/format->magnitude,
+               format->units);    
+    gtk_label_set_markup(GTK_LABEL(tool->average_label), result);
 }
 
 static void
