@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: pathlevel.c 8712 2008-01-25 09:30:13Z yeti-dn $
+ *  @(#) $Id: pathlevel.c 8806 2008-11-28 10:28:14Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -108,7 +108,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Path level tool, performs row leveling along on user-set lines."),
     "Yeti <yeti@gwyddion.net>",
-    "1.2",
+    "1.3",
     "David Nečas (Yeti)",
     "2007",
 };
@@ -292,6 +292,7 @@ gwy_tool_path_level_data_switched(GwyTool *gwytool,
     if (data_view) {
         gwy_object_set_or_reset(plain_tool->layer,
                                 tool->layer_type_line,
+                                "thickness", tool->args.thickness,
                                 "editable", TRUE,
                                 "focus", -1,
                                 NULL);
@@ -349,7 +350,14 @@ static void
 gwy_tool_path_level_thickness_changed(GwyToolPathLevel *tool,
                                       GtkAdjustment *adj)
 {
+    GwyPlainTool *plain_tool;
+
     tool->args.thickness = gwy_adjustment_get_int(adj);
+    plain_tool = GWY_PLAIN_TOOL(tool);
+    if (plain_tool->layer)
+        g_object_set(plain_tool->layer,
+                     "thickness", tool->args.thickness,
+                     NULL);
     /* TODO? */
 }
 
